﻿using Microsoft.Azure.Management.Storage;
using Microsoft.Azure.Management.Storage.Models;
using Microsoft.Rest;

using System;
using System.Linq;

namespace AzureBlob
{

   /// <summary>
   /// Azure Blob Storage Client library sample
   ///       The Azure Blob Storage Client library has been added to this project by the following command in the NuGet Package Manager Console:
   ///       <code>dotnet add package Azure.Storage.Blobs</code>
   /// </summary>


   class Program
   {
      static void Main(string[] args)
      {
         string ContainerName = "<Your_ContainerName_Here>";
         string ConnectionString = "<Your_ConnectionString_Here>";
         string SourceFileName = @"<Your_SourceFileName_Here>";
         string DestinationFileName = @"<Your_DestinationFileName_Here>";
         string BlobName = "<Your_BlobName_Here>";
         Char resp = ' ';

         while (!"10".ToCharArray().Contains(resp))
         {

            Console.Clear();
            Console.Write(Properties.Resources.ConsoleMsg);
            resp = Console.ReadKey(false).KeyChar;
         }
         if (resp == '1')
         {
            UsingBlob(ContainerName, ConnectionString, SourceFileName, DestinationFileName, BlobName);

         }
      }
      /// <summary>
      /// This function demonstrates the creation of a blob container 
      /// and how to upload content to it
      /// </summary>
      /// <param name="ContainerName"> name of the container to create</param>
      /// <param name="ConnectionString">Connection string for the Azure Storage account</param>
      /// <param name="SourceFileName">Path and name of the file to use for upload test</param>
      /// <param name="DestinationFileName">Path and name of the file to use as destination for download test</param>
      /// <param name="BlobName">Name to assign to the content in the container/></param>
      private static void UsingBlob(String ContainerName, String ConnectionString, String SourceFileName, String DestinationFileName, String BlobName)
      {
         Console.ForegroundColor = System.ConsoleColor.Cyan;
         Console.WriteLine("Parameters used:");
         Console.WriteLine($"ContainerName = [{ContainerName}]");
         Console.WriteLine($"ConnectionString= [{ConnectionString}]");
         Console.WriteLine($"SourceFileName = [{SourceFileName}]");
         Console.WriteLine($"DestinationFileName = [{DestinationFileName}]");
         Console.WriteLine($"BlobName = [{BlobName}]");
         Console.ForegroundColor = System.ConsoleColor.White;
         Console.WriteLine("Press Any Key to Continue");
         Console.ReadKey();
         Console.ForegroundColor = System.ConsoleColor.Green;
         Console.WriteLine("Creating Service Client");
         Azure.Storage.Blobs.BlobServiceClient blobServiceClient = new Azure.Storage.Blobs.BlobServiceClient(ConnectionString);
         Console.WriteLine("Creating Blob Container Client");
         Azure.Storage.Blobs.BlobContainerClient blobContainerClient = blobServiceClient.GetBlobContainerClient(ContainerName);
         Console.WriteLine($"Uploading file [{SourceFileName}] as [{BlobName}] blob");
         blobContainerClient.GetBlobClient(BlobName).Upload(SourceFileName);
         Console.WriteLine($"Downloading blob [{BlobName}]  to file [{DestinationFileName}]  ");
         blobContainerClient.GetBlobClient(BlobName).DownloadTo(DestinationFileName);
         Console.ForegroundColor = System.ConsoleColor.White;
         Console.WriteLine("Press Any Key to exit");
      }
      /// <summary>
      ///   Sample function to demonstrate how to create a Storage account from an application
      /// </summary>
      /// <param name="credentials"><see cref="ServiceClientCredentials"/> for the Subscription connection</param>
      /// <param name="resourceGroupName">Name of the Resource Group where add the Storage account</param>
      /// <param name="accountName">Name of the account to add</param>
      /// <param name="sku"><see cref="Sku"/> of the account</param>
      /// <param name="location">Geographical location for the storage account</param>
      /// <param name="kind">Kind name of the account</param>
      private static async void CreateStorageAccount(
            ServiceClientCredentials credentials,
            string resourceGroupName,
            string accountName,
            Sku sku,
            string location,
            string kind)
      {
         StorageAccountCreateParameters parameters = new StorageAccountCreateParameters(sku, kind, location);
         StorageManagementClient storageManagementClient = new StorageManagementClient(credentials);
         var resp = await storageManagementClient.StorageAccounts.CreateAsync(resourceGroupName, accountName,
                              parameters
                         );
      }
   }
}
